import { scaleOrdinal } from 'd3-scale';
import { schemeSet1 } from 'd3-scale-chromatic';
import { produce } from 'immer';
import React, { useMemo, useReducer } from 'react';
import TransparentRect from './components/TransparentRect';
import { LegendProvider } from './components/legendsContext';
import { PlotContext, DispatchContext, useAxisContext } from './hooks';
import { reducer } from './plotReducer';
import { splitChildren } from './utils';
const reducerCurr = produce(reducer);
const initialState = {
    series: [],
    axis: {},
};
export default function Plot({ width, height, margin = {}, colorScheme, children, style = {}, viewportStyle = {}, }) {
    const [state, dispatch] = useReducer(reducerCurr, initialState, undefined);
    const { hasInvalidChild, series, axes, heading, legend } = splitChildren(children);
    if (hasInvalidChild) {
        throw new Error('Only compound components of Plot are displayed');
    }
    // Distances in plot
    const { left = 0, right = 0, top = 0, bottom = 0 } = margin;
    const plotWidth = width - left - right;
    const plotHeight = height - top - bottom;
    // Set scales
    const axisContext = useAxisContext(state, {
        plotWidth,
        plotHeight,
    });
    const labels = useMemo(() => state.series.map(({ id, label }) => ({ id, label })), [state.series]);
    const ids = useMemo(() => state.series.map(({ id }) => id), [state.series]);
    const colorScaler = useMemo(() => {
        return scaleOrdinal()
            .range(colorScheme || schemeSet1)
            .domain(ids);
    }, [colorScheme, ids]);
    return (React.createElement(PlotContext.Provider, { value: {
            width,
            height,
            left,
            right,
            top,
            bottom,
            plotWidth,
            plotHeight,
            labels,
            colorScaler,
            axisContext,
        } },
        React.createElement(DispatchContext.Provider, { value: { dispatch } },
            React.createElement(LegendProvider, null,
                React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: width, height: height, style: { fontFamily: 'Arial, Helvetica, sans-serif' } },
                    React.createElement(TransparentRect, { width: width, height: height, style: style }),
                    React.createElement("g", { transform: `translate(${left}, ${top})` },
                        React.createElement(TransparentRect, { width: plotWidth, height: plotHeight, style: viewportStyle }),
                        React.createElement("clipPath", { id: "viewportClip" },
                            React.createElement("rect", { width: plotWidth, height: plotHeight })),
                        React.createElement("g", { style: { clipPath: 'url(#viewportClip)' } }, series),
                        axes),
                    heading,
                    legend)))));
}
//# sourceMappingURL=Plot.js.map