import React, { useMemo } from 'react';
import { usePlotContext } from '../../hooks';
import { calculateTicksNumber } from '../../utils';
import { Ticks } from './Ticks';
export default function BottomAxis({ id, displayGridLines, hidden = false, label, labelSpace, labelStyle, fontSize, tickStyle, hiddenTicks = false, tickEmbedded, tickLength, }) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    // Calculates the main axis values
    const { scale, scientific } = axisContext[id] || {};
    const ticks = useMemo(() => {
        const ticksNumber = calculateTicksNumber(plotWidth, scientific, scale === null || scale === void 0 ? void 0 : scale.domain());
        return (scale === null || scale === void 0 ? void 0 : scale.ticks(ticksNumber)) || [];
    }, [scale, scientific, plotWidth]);
    const range = (scale === null || scale === void 0 ? void 0 : scale.range()) || [0, 0];
    // Create gridlines
    const gridlines = useMemo(() => {
        if (!displayGridLines || !scale)
            return null;
        return (React.createElement("g", { className: "gridLines" }, ticks.map((val) => (React.createElement("line", { key: val, x1: scale(val), x2: scale(val), y1: plotHeight, y2: "0", stroke: "black", strokeDasharray: "2,2", strokeOpacity: 0.5 })))));
    }, [displayGridLines, ticks, scale, plotHeight]);
    const tickDirection = tickEmbedded ? -1 : 1;
    const tickLen = tickDirection * tickLength;
    return (React.createElement("g", { className: "axis" },
        gridlines,
        !hidden && (React.createElement("g", { className: "ticks", transform: `translate(0, ${plotHeight})` },
            React.createElement("line", { x1: range[0], x2: range[1], stroke: "black" }),
            React.createElement(Ticks, { scientific: scientific, scale: scale, hidden: hiddenTicks, ticks: ticks, style: tickStyle, anchor: "middle", getPositions: (val) => ({
                    line: { x1: val, x2: val, y2: tickLen },
                    text: { x1: val, y1: 16 },
                }) }))),
        label && !hidden && (React.createElement("text", { x: plotWidth / 2, y: plotHeight + labelSpace + fontSize, fontSize: fontSize, textAnchor: "middle", style: labelStyle }, label))));
}
//# sourceMappingURL=BottomAxis.js.map