import React, { useMemo } from 'react';
import { usePlotContext } from '../../hooks';
import VerticalText from '../VerticalText';
import { Ticks } from './Ticks';
export default function RightAxis({ id, displayGridLines, hidden = false, label, labelSpace, labelStyle, fontSize, tickStyle, hiddenTicks = false, tickEmbedded, tickLength, }) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    // Calculates the main axis values
    const { scale, scientific } = axisContext[id] || {};
    const ticks = useMemo(() => (scale === null || scale === void 0 ? void 0 : scale.ticks()) || [], [scale]);
    const range = (scale === null || scale === void 0 ? void 0 : scale.range()) || [0, 0];
    // Create gridlines
    const gridlines = useMemo(() => {
        if (!displayGridLines || !scale)
            return null;
        return (React.createElement("g", { className: "gridLines" }, ticks.map((val) => (React.createElement("line", { key: val, x1: "0", x2: plotWidth, y1: scale(val), y2: scale(val), stroke: "black", strokeDasharray: "2,2", strokeOpacity: 0.5 })))));
    }, [displayGridLines, ticks, scale, plotWidth]);
    const tickDirection = tickEmbedded ? -1 : 1;
    const tickLen = tickDirection * tickLength;
    return (React.createElement("g", { className: "axis" },
        gridlines,
        !hidden && (React.createElement("g", { className: "ticks", transform: `translate(${plotWidth} 0)` },
            React.createElement("line", { y1: range[0], y2: range[1], stroke: "black" }),
            React.createElement(Ticks, { scientific: scientific, scale: scale, hidden: hiddenTicks, ticks: ticks, style: tickStyle, anchor: "begin", getPositions: (y) => ({
                    line: { x2: tickLen, y1: y, y2: y },
                    text: { x1: 10, y1: y },
                }) }))),
        label && !hidden && (React.createElement(VerticalText, { label: label, dy: fontSize, fontSize: fontSize, style: labelStyle, transform: `translate(${plotWidth + fontSize + labelSpace + (scientific ? 14 : 0)}, ${plotHeight / 2})` }))));
}
//# sourceMappingURL=RightAxis.js.map