/* eslint-disable react/no-array-index-key */
import React, { useMemo } from 'react';
import { usePlotContext } from '../hooks';
import { markersComps } from './Markers';
import { useLegend } from './legendsContext';
export function exclusiveProps(margins, a, b, position) {
    if (margins[a] !== undefined) {
        if (margins[b] !== undefined) {
            throw new Error(`${a} and ${b} should't be both defined for the position ${position}`);
        }
        return { key: a, value: margins[a] };
    }
    return margins[b] !== undefined ? { key: b, value: margins[b] } : {};
}
function translation(position, legendMargins, plotMargins, width, height) {
    const plotHeight = height - plotMargins.top - plotMargins.bottom;
    const plotWidth = width - plotMargins.left - plotMargins.right;
    switch (position) {
        case 'embedded': {
            const { key: verticalKey = 'top', value: verticalValue = 10, } = exclusiveProps(legendMargins, 'top', 'bottom', position);
            const { key: horizontalKey = 'left', value: horizontalValue = 10, } = exclusiveProps(legendMargins, 'left', 'right', position);
            const x = horizontalKey === 'right'
                ? width - plotMargins.right - horizontalValue
                : plotMargins.left + horizontalValue;
            const y = verticalKey === 'bottom'
                ? height - plotMargins.bottom - verticalValue
                : plotMargins.top + verticalValue;
            return [x, y];
        }
        case 'top': {
            const { key: horizontalKey = 'left', value: horizontalValue = plotWidth / 2, } = exclusiveProps(legendMargins, 'left', 'right', position);
            const x = horizontalKey === 'right'
                ? width - plotMargins.right + horizontalValue
                : plotMargins.left + horizontalValue;
            const y = plotMargins.top - (legendMargins.bottom || 50);
            return [x, y];
        }
        case 'bottom': {
            const { key: horizontalKey = 'left', value: horizontalValue = plotWidth / 2, } = exclusiveProps(legendMargins, 'left', 'right', position);
            const x = horizontalKey === 'right'
                ? width - plotMargins.right + horizontalValue
                : plotMargins.left + horizontalValue;
            const y = height - plotMargins.bottom + (legendMargins.top || 25);
            return [x, y];
        }
        case 'left': {
            const { key: verticalKey = 'top', value: verticalValue = plotHeight / 2, } = exclusiveProps(legendMargins, 'top', 'bottom', position);
            const y = verticalKey === 'bottom'
                ? height - plotMargins.bottom - verticalValue
                : plotMargins.top + verticalValue;
            const x = plotMargins.left - (legendMargins.right || 100);
            return [x, y];
        }
        case 'right': {
            const { key: verticalKey = 'top', value: verticalValue = plotHeight / 2, } = exclusiveProps(legendMargins, 'top', 'bottom', position);
            const y = verticalKey === 'bottom'
                ? height - plotMargins.bottom - verticalValue
                : plotMargins.top + verticalValue;
            const x = width - plotMargins.right + (legendMargins.left || 40);
            return [x, y];
        }
        default: {
            throw new Error(`Position ${JSON.stringify(position)} unknown`);
        }
    }
}
export default function Legend({ position, ...legendMargins }) {
    const { right, left, top, bottom, height, width } = usePlotContext();
    const [state] = useLegend();
    const [x, y] = useMemo(() => {
        const plotMargins = { right, left, top, bottom };
        return translation(position, legendMargins, plotMargins, width, height);
    }, [position, legendMargins, right, left, top, bottom, width, height]);
    return (React.createElement("g", { className: "legend", transform: `translate(${x}, ${y})` }, state.labels.map((value, index) => {
        const xPos = 10;
        const yPos = (index + 1) * 16 - xPos + 5;
        const Marker = markersComps[value.shape.figure];
        return (React.createElement("g", { key: `${value.colorLine}/${value.shape.color}-${value.label}`, transform: `translate(${xPos}, ${0})` },
            getLineShape({ index, color: value.colorLine }),
            React.createElement("g", { transform: `translate(${xPos - 1}, ${yPos})` }, !value.shape.hidden && (React.createElement(Marker, { size: 10, style: { fill: value.shape.color } }))),
            React.createElement("text", { key: `text-${value.label}-${index}`, x: 30, y: `${index + 1}em` }, value.label)));
    })));
}
function getLineShape(config) {
    const x = 0;
    const y = (config.index + 1) * 16 - x - 7;
    return React.createElement("rect", { x: x, y: y, width: "20", height: "3", fill: config.color });
}
//# sourceMappingURL=Legend.js.map