import { line } from 'd3-shape';
import React, { useEffect, useMemo, useState } from 'react';
import { usePlotContext } from '../hooks';
import { getNextId, validateAxis } from '../utils';
import ScatterSeries from './ScatterSeries';
import { useLegend } from './legendsContext';
export default function LineSeries(props) {
    var _a;
    const [, legendDispatch] = useLegend();
    const { colorScaler } = usePlotContext();
    const [id] = useState(() => props.groupId || `series-${getNextId()}`);
    const { lineStyle = {}, displayMarker = false, ...otherProps } = props;
    const lineProps = {
        id,
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        lineStyle,
    };
    useEffect(() => {
        var _a;
        legendDispatch({
            type: 'ADD_LEGEND_LABEL',
            payload: {
                label: otherProps.label,
                colorLine: (lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke) ? lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke.toString() : colorScaler(id),
                shape: {
                    color: ((_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill.toString()) || colorScaler(id),
                    figure: otherProps.markerShape || 'circle',
                    hidden: !displayMarker,
                },
            },
        });
    }, [
        colorScaler,
        displayMarker,
        id,
        legendDispatch,
        lineStyle,
        lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke,
        otherProps.label,
        otherProps.markerShape,
        otherProps.markerStyle,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    return (React.createElement("g", null,
        props.hidden ? null : React.createElement(LineSeriesRender, Object.assign({}, lineProps)),
        React.createElement(ScatterSeries, Object.assign({}, otherProps, { hidden: !displayMarker || props.hidden, groupId: id }))));
}
function LineSeriesRender({ id, data, xAxis, yAxis, lineStyle, }) {
    // Get scales from context
    const { axisContext, colorScaler } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, xAxis, yAxis);
    // calculates the path to display
    const color = colorScaler(id);
    const path = useMemo(() => {
        if ([xScale, yScale].includes(undefined))
            return null;
        // Calculate line from D3
        const lineGenerator = line()
            .x((d) => xScale(d.x))
            .y((d) => yScale(d.y));
        return lineGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return React.createElement("path", { style: style, d: path, fill: "none" });
}
//# sourceMappingURL=LineSeries.js.map