import { produce } from 'immer';
import React, { createContext, useContext, useReducer, } from 'react';
const context = createContext(null);
export function useLegend() {
    const ctx = useContext(context);
    if (!ctx) {
        throw new Error('context was not initialized');
    }
    return ctx;
}
const legendReducer = produce((draft, action) => {
    switch (action.type) {
        case 'ADD_LEGEND_LABEL': {
            const { shape, ...other } = action.payload;
            if (draft.labels.some((element) => element.label === other.label)) {
                return;
            }
            draft.labels.push({ ...other, shape });
            return;
        }
        default:
            throw new Error('unreachable');
    }
});
const initialLegendState = {
    labels: [],
};
export const LegendProvider = (props) => {
    const ctx = useReducer(legendReducer, initialLegendState);
    return React.createElement(context.Provider, { value: ctx }, props.children);
};
//# sourceMappingURL=legendsContext.js.map