"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const d3_scale_1 = require("d3-scale");
const d3_scale_chromatic_1 = require("d3-scale-chromatic");
const immer_1 = require("immer");
const react_1 = __importStar(require("react"));
const TransparentRect_1 = __importDefault(require("./components/TransparentRect"));
const legendsContext_1 = require("./components/legendsContext");
const hooks_1 = require("./hooks");
const plotReducer_1 = require("./plotReducer");
const utils_1 = require("./utils");
const reducerCurr = immer_1.produce(plotReducer_1.reducer);
const initialState = {
    series: [],
    axis: {},
};
function Plot({ width, height, margin = {}, colorScheme, children, style = {}, viewportStyle = {}, }) {
    const [state, dispatch] = react_1.useReducer(reducerCurr, initialState, undefined);
    const { hasInvalidChild, series, axes, heading, legend } = utils_1.splitChildren(children);
    if (hasInvalidChild) {
        throw new Error('Only compound components of Plot are displayed');
    }
    // Distances in plot
    const { left = 0, right = 0, top = 0, bottom = 0 } = margin;
    const plotWidth = width - left - right;
    const plotHeight = height - top - bottom;
    // Set scales
    const axisContext = hooks_1.useAxisContext(state, {
        plotWidth,
        plotHeight,
    });
    const labels = react_1.useMemo(() => state.series.map(({ id, label }) => ({ id, label })), [state.series]);
    const ids = react_1.useMemo(() => state.series.map(({ id }) => id), [state.series]);
    const colorScaler = react_1.useMemo(() => {
        return d3_scale_1.scaleOrdinal()
            .range(colorScheme || d3_scale_chromatic_1.schemeSet1)
            .domain(ids);
    }, [colorScheme, ids]);
    return (react_1.default.createElement(hooks_1.PlotContext.Provider, { value: {
            width,
            height,
            left,
            right,
            top,
            bottom,
            plotWidth,
            plotHeight,
            labels,
            colorScaler,
            axisContext,
        } },
        react_1.default.createElement(hooks_1.DispatchContext.Provider, { value: { dispatch } },
            react_1.default.createElement(legendsContext_1.LegendProvider, null,
                react_1.default.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: width, height: height, style: { fontFamily: 'Arial, Helvetica, sans-serif' } },
                    react_1.default.createElement(TransparentRect_1.default, { width: width, height: height, style: style }),
                    react_1.default.createElement("g", { transform: `translate(${left}, ${top})` },
                        react_1.default.createElement(TransparentRect_1.default, { width: plotWidth, height: plotHeight, style: viewportStyle }),
                        react_1.default.createElement("clipPath", { id: "viewportClip" },
                            react_1.default.createElement("rect", { width: plotWidth, height: plotHeight })),
                        react_1.default.createElement("g", { style: { clipPath: 'url(#viewportClip)' } }, series),
                        axes),
                    heading,
                    legend)))));
}
exports.default = Plot;
