"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const d3_shape_1 = require("d3-shape");
const react_1 = __importStar(require("react"));
const hooks_1 = require("../hooks");
const utils_1 = require("../utils");
const ScatterSeries_1 = __importDefault(require("./ScatterSeries"));
const legendsContext_1 = require("./legendsContext");
function LineSeries(props) {
    var _a;
    const [, legendDispatch] = legendsContext_1.useLegend();
    const { colorScaler } = hooks_1.usePlotContext();
    const [id] = react_1.useState(() => props.groupId || `series-${utils_1.getNextId()}`);
    const { lineStyle = {}, displayMarker = false, ...otherProps } = props;
    const lineProps = {
        id,
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        lineStyle,
    };
    react_1.useEffect(() => {
        var _a;
        legendDispatch({
            type: 'ADD_LEGEND_LABEL',
            payload: {
                label: otherProps.label,
                colorLine: (lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke) ? lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke.toString() : colorScaler(id),
                shape: {
                    color: ((_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill.toString()) || colorScaler(id),
                    figure: otherProps.markerShape || 'circle',
                    hidden: !displayMarker,
                },
            },
        });
    }, [
        colorScaler,
        displayMarker,
        id,
        legendDispatch,
        lineStyle,
        lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke,
        otherProps.label,
        otherProps.markerShape,
        otherProps.markerStyle,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    return (react_1.default.createElement("g", null,
        props.hidden ? null : react_1.default.createElement(LineSeriesRender, Object.assign({}, lineProps)),
        react_1.default.createElement(ScatterSeries_1.default, Object.assign({}, otherProps, { hidden: !displayMarker || props.hidden, groupId: id }))));
}
exports.default = LineSeries;
function LineSeriesRender({ id, data, xAxis, yAxis, lineStyle, }) {
    // Get scales from context
    const { axisContext, colorScaler } = hooks_1.usePlotContext();
    const [xScale, yScale] = utils_1.validateAxis(axisContext, xAxis, yAxis);
    // calculates the path to display
    const color = colorScaler(id);
    const path = react_1.useMemo(() => {
        if ([xScale, yScale].includes(undefined))
            return null;
        // Calculate line from D3
        const lineGenerator = d3_shape_1.line()
            .x((d) => xScale(d.x))
            .y((d) => yScale(d.y));
        return lineGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return react_1.default.createElement("path", { style: style, d: path, fill: "none" });
}
