"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const d3_array_1 = require("d3-array");
const react_1 = __importStar(require("react"));
const hooks_1 = require("../hooks");
const utils_1 = require("../utils");
const Markers_1 = require("./Markers");
function ScatterSeries(props) {
    const [id] = react_1.useState(() => props.groupId || `series-${utils_1.getNextId()}`);
    const { xAxis = 'x', yAxis = 'y', data, label, ...otherProps } = props;
    // Update plot context with data description
    const { dispatch } = hooks_1.useDispatchContext();
    react_1.useEffect(() => {
        const [xMin, xMax] = d3_array_1.extent(data, (d) => d.x);
        const [yMin, yMax] = d3_array_1.extent(data, (d) => d.y);
        const x = { min: xMin, max: xMax, axisId: xAxis };
        const y = { min: yMin, max: yMax, axisId: yAxis };
        dispatch({ type: 'newData', value: { id, x, y, label } });
        // Delete information on unmount
        return () => dispatch({ type: 'removeData', value: { id } });
    }, [dispatch, id, data, xAxis, yAxis, label]);
    if (props.hidden)
        return null;
    // Render stateless plot component
    const inheretedProps = { data, id, xAxis, yAxis };
    return react_1.default.createElement(ScatterSeriesRender, Object.assign({}, otherProps, inheretedProps, { id: id }));
}
exports.default = ScatterSeries;
function ScatterSeriesRender({ id, data, xAxis, yAxis, markerShape = 'circle', markerSize = 8, markerStyle = {}, }) {
    // Get scales from context
    const { axisContext, colorScaler } = hooks_1.usePlotContext();
    const [xScale, yScale] = utils_1.validateAxis(axisContext, xAxis, yAxis);
    // calculates the path to display
    const markers = react_1.useMemo(() => {
        if ([xScale, yScale].includes(undefined))
            return null;
        const color = colorScaler(id);
        const defaultColor = { fill: color, stroke: color };
        // Show markers
        const Marker = Markers_1.markersComps[markerShape];
        const markers = data.map((point, i) => {
            return (react_1.default.createElement("g", { key: `markers-${i}`, transform: `translate(${xScale(point.x)}, ${yScale(point.y)})` },
                react_1.default.createElement(Marker, { size: markerSize, style: utils_1.functionalStyle(defaultColor, markerStyle, point, i, data) })));
        });
        return markers;
    }, [
        xScale,
        yScale,
        colorScaler,
        id,
        data,
        markerSize,
        markerStyle,
        markerShape,
    ]);
    if (!markers)
        return null;
    return react_1.default.createElement("g", { className: "markers" }, markers);
}
