"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAxisContext = exports.useDispatchContext = exports.usePlotContext = exports.DispatchContext = exports.PlotContext = void 0;
const d3_array_1 = require("d3-array");
const d3_scale_1 = require("d3-scale");
const react_1 = require("react");
exports.PlotContext = react_1.createContext({
    axisContext: {},
});
exports.DispatchContext = react_1.createContext({
    dispatch: null,
});
function usePlotContext() {
    const context = react_1.useContext(exports.PlotContext);
    if (!context) {
        throw new Error('Plot compound component outside Plot context');
    }
    return context;
}
exports.usePlotContext = usePlotContext;
function useDispatchContext() {
    const context = react_1.useContext(exports.DispatchContext);
    if (!context) {
        throw new Error('Plot compound component outside Dispatch context');
    }
    return context;
}
exports.useDispatchContext = useDispatchContext;
function useAxisContext(state, { plotWidth, plotHeight }) {
    const context = react_1.useMemo(() => {
        let axisContext = {};
        for (const id in state.axis) {
            const axis = state.axis[id];
            const isHorizontal = ['top', 'bottom'].includes(axis.position);
            const xY = isHorizontal ? 'x' : 'y';
            // Get limits from state or data
            const axisMin = axis.min !== undefined ? axis.min : d3_array_1.min(state.series, (d) => d[xY].min);
            const axisMax = axis.max !== undefined ? axis.max : d3_array_1.max(state.series, (d) => d[xY].max);
            // Limits validation
            if ([axisMin, axisMax].includes(undefined))
                return {};
            if (axisMin > axisMax) {
                throw new Error(`${id}: min (${axisMin}) is bigger than max (${axisMax})`);
            }
            // Limits paddings
            const diff = axisMax - axisMin;
            const minPad = diff * axis.paddingStart;
            const maxPad = diff * axis.paddingEnd;
            const range = isHorizontal ? [0, plotWidth] : [plotHeight, 0];
            axisContext[id] = {
                position: axis.position,
                scientific: diff <= 0.01 || diff >= 1000,
                scale: d3_scale_1.scaleLinear()
                    .domain([axisMin - minPad, axisMax + maxPad])
                    .range(axis.flip ? range.reverse() : range),
            };
        }
        return axisContext;
    }, [state, plotWidth, plotHeight]);
    return context;
}
exports.useAxisContext = useAxisContext;
